import pygame
from . import engine
from .data import load, read_json

class Animation:
	def __init__(self, frames, fps, flip=False):
		self.frames = frames
		self.flipped = []
		for frame in frames:
			self.flipped.append(pygame.transform.flip(frame, True, False))
		if flip:
			self.frames, self.flipped = self.flipped, self.frames
		self.fps = fps

	def get(self, timer, flipped):
		framecount = len(self.frames)
		frametime = 1.0/self.fps
		fulltime = frametime * framecount
		timer %= fulltime
		timer /= fulltime
		frameid = int(timer * framecount)
		frameid %= framecount
		if flipped:
			return self.flipped[frameid]
		return self.frames[frameid]

def load_animation(filename, size, flip=False):
	jsondata = read_json(filename)
	fps = jsondata.get('fps', 10)
	rawframes = jsondata['frames']
	frames = []
	for framefile in rawframes:
		frame = pygame.image.load(load(framefile), framefile)
		frame = pygame.transform.scale(frame, size)
		frames.append(frame)

	return Animation(frames, fps, flip)
